@@ -81,7 +81,8 @@ store_gconf_settings(const gchar* profile_name,
   g_assert(GCONF_IS_CLIENT(client));
   gchar* profile_name_key = gconf_escape_key(profile_name, -1);
   if(!profile_data->autoanswer &&
-     !profile_data->turn_speaker_on)
+     !profile_data->turn_speaker_on &&
+     !profile_data->disable_proximity_check)
   {
     gchar* profile_conf_key = g_strdup_printf("%s/%s", GC_ROOT, profile_name_key);
     gconf_client_recursive_unset(client, profile_conf_key, GCONF_UNSET_INCLUDING_SCHEMA_NAMES, NULL);
@@ -90,11 +91,14 @@ store_gconf_settings(const gchar* profile_name,
   else
   {
     gchar* autoanswer_conf_key = g_strdup_printf("%s/%s/autoAnswer", GC_ROOT, profile_name_key);
+    gchar* disable_proximity_check_conf_key = g_strdup_printf("%s/%s/disableProximityCheck", GC_ROOT, profile_name_key);
     gchar* turnspeakeron_conf_key = g_strdup_printf("%s/%s/turnSpeakerOn", GC_ROOT, profile_name_key);
     gconf_client_set_bool(client, autoanswer_conf_key, profile_data->autoanswer, NULL);
+    gconf_client_set_bool(client, disable_proximity_check_conf_key, profile_data->disable_proximity_check, NULL);
     gconf_client_set_bool(client, turnspeakeron_conf_key, profile_data->turn_speaker_on, NULL);
     g_free(turnspeakeron_conf_key);
     g_free(autoanswer_conf_key);
+    g_free(disable_proximity_check_conf_key);
   }
   g_free(profile_name_key);
   g_object_unref(client);
@@ -168,11 +172,14 @@ load_gconf_settings(const gchar* profile_name,
 
   gchar* profile_name_key = gconf_escape_key(profile_name, -1);
   gchar* autoanswer_conf_key = g_strdup_printf("%s/%s/autoAnswer", GC_ROOT, profile_name_key);
+  gchar* disable_proximity_check_conf_key = g_strdup_printf("%s/%s/disableProximityCheck", GC_ROOT, profile_name_key);
   gchar* turnspeakeron_conf_key = g_strdup_printf("%s/%s/turnSpeakerOn", GC_ROOT, profile_name_key);
   profile_data->autoanswer = gconf_client_get_bool(client, autoanswer_conf_key, NULL);
+  profile_data->disable_proximity_check = gconf_client_get_bool(client, disable_proximity_check_conf_key, NULL);
   profile_data->turn_speaker_on = gconf_client_get_bool(client, turnspeakeron_conf_key, NULL);
   g_free(turnspeakeron_conf_key);
   g_free(autoanswer_conf_key);
+  g_free(disable_proximity_check_conf_key);
   g_free(profile_name_key);
   g_object_unref(client);
 }
