@@ -624,7 +624,7 @@ profilesx_status_plugin_init(ProfilesxStatusPlugin* plugin)
   plugin->priv->button = hildon_button_new(HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT,
 					   HILDON_BUTTON_ARRANGEMENT_VERTICAL);
 
-  hildon_button_set_title(HILDON_BUTTON(plugin->priv->button), "ProfilesX");
+  hildon_button_set_title(HILDON_BUTTON(plugin->priv->button), dgettext("osso-profiles", "profi_ti_menu_plugin"));
   g_signal_connect(plugin->priv->button, "clicked", G_CALLBACK(show_profile_selection_dlg), plugin);
   g_signal_connect(plugin, "unrealize", G_CALLBACK(show_original_profile_button), NULL); 
   GtkWidget *image;
